@@ -62,7 +62,7 @@ class StorageGenerator(AzureGenerator):
     )
     ADDITIONAL_INFO = [None]
 
-    def __init__(self, start_date, end_date, account_info, attributes=None):
+    def __init__(self, start_date, end_date, currency, account_info, attributes=None):
         """Initialize the data transfer generator."""
         self._service_name = "Storage"
-        super().__init__(start_date, end_date, account_info, attributes)
+        super().__init__(start_date, end_date, currency, account_info, attributes)
