@@ -57,6 +57,10 @@ class CloudStorageGenerator(GCPGenerator):
                 self._price = self.attributes.get("price")
             if self.attributes.get("credit_amount"):
                 self._credit_amount = self.attributes.get("credit_amount")
+            if self.attributes.get("resource.name"):
+                self._resource_name = self.attributes.get("resource.name")
+            if self.attributes.get("resource.global_name"):
+                self._resource_global_name = self.attributes.get("resource.global_name")
 
     def _update_data(self, row):  # noqa: C901
         """Update a data row with compute values."""
@@ -92,6 +96,12 @@ class CloudStorageGenerator(GCPGenerator):
         row["currency"] = self._currency
         row["labels"] = self.determine_labels(self.LABELS)
         row["system_labels"] = choice(self.SYSTEM_LABELS)
+        if self.resource_level:
+            resource = self._generate_resource(
+                self._resource_name, self._resource_global_name, self.project.get("region")
+            )
+            row["resource.name"] = resource.get("name")
+            row["resource.global_name"] = resource.get("global_name")
 
         return row
 
@@ -107,7 +117,9 @@ class JSONLCloudStorageGenerator(CloudStorageGenerator):
 
     def __init__(self, start_date, end_date, currency, project, attributes=None):
         super().__init__(start_date, end_date, currency, project, attributes)
-        self.column_labels = GCP_REPORT_COLUMNS_JSONL
+        self.column_labels = (
+            GCP_REPORT_COLUMNS_JSONL + ("resource",) if self.resource_level else GCP_REPORT_COLUMNS_JSONL
+        )
         self.return_list = True
 
     def _update_data(self, row):  # noqa: C901
@@ -143,6 +155,9 @@ class JSONLCloudStorageGenerator(CloudStorageGenerator):
         month = datetime.strptime(row.get("usage_start_time"), "%Y-%m-%dT%H:%M:%S").month
         invoice["month"] = f"{year}{month:02d}"
         row["invoice"] = invoice
+        if self.resource_level:
+            resource = self._generate_resource()
+            row["resource"] = resource
 
         if self.attributes:
             for key in self.attributes:
