@@ -47,7 +47,7 @@ class GCPNetworkGenerator(GCPGenerator):
 
     LABELS = (([{"key": "vm_key_proj2", "value": "vm_label_proj2"}]), ([]))
 
-    def __init__(self, start_date, end_date, currency, project, attributes=None):
+    def __init__(self, start_date, end_date, currency, project, attributes=None):  # noqa: C901
         """Initialize the cloud storage generator."""
         super().__init__(start_date, end_date, currency, project, attributes)
         self.credit_total = 0
@@ -67,6 +67,10 @@ class GCPNetworkGenerator(GCPGenerator):
                         self._service = service
             if self.attributes.get("credit_amount"):
                 self._credit_amount = self.attributes.get("credit_amount")
+            if self.attributes.get("resource.name"):
+                self._resource_name = self.attributes.get("resource.name")
+            if self.attributes.get("resource.global_name"):
+                self._resource_global_name = self.attributes.get("resource.global_name")
 
     def _update_data(self, row):  # noqa: C901
         """Update a data row with compute values."""
@@ -102,6 +106,12 @@ class GCPNetworkGenerator(GCPGenerator):
 
         row["currency"] = self._currency
         row["labels"] = self.determine_labels(self.LABELS)
+        if self.resource_level:
+            resource = self._generate_resource(
+                self._resource_name, self._resource_global_name, self.project.get("region")
+            )
+            row["resource.name"] = resource.get("name")
+            row["resource.global_name"] = resource.get("global_name")
 
         return row
 
@@ -117,7 +127,9 @@ class JSONLGCPNetworkGenerator(GCPNetworkGenerator):
 
     def __init__(self, start_date, end_date, currency, project, attributes=None):
         super().__init__(start_date, end_date, currency, project, attributes)
-        self.column_labels = GCP_REPORT_COLUMNS_JSONL
+        self.column_labels = (
+            GCP_REPORT_COLUMNS_JSONL + ("resource",) if self.resource_level else GCP_REPORT_COLUMNS_JSONL
+        )
         self.return_list = True
 
     def _update_data(self, row):  # noqa: C901
@@ -155,6 +167,9 @@ class JSONLGCPNetworkGenerator(GCPNetworkGenerator):
         usage_date = datetime.strptime(row.get("usage_start_time"), "%Y-%m-%dT%H:%M:%S")
         invoice["month"] = f"{usage_date.year}{usage_date.month:02d}"
         row["invoice"] = invoice
+        if self.resource_level:
+            resource = self._generate_resource()
+            row["resource"] = resource
 
         if self.attributes:
             for key in self.attributes:
