@@ -35,6 +35,7 @@ from oci.config import from_file
 from oci.config import validate_config
 from oci.exceptions import ConfigFileNotFound
 from oci.exceptions import InvalidConfig
+from oci.exceptions import InvalidPrivateKey
 from oci.exceptions import ServiceError
 from oci.object_storage import ObjectStorageClient
 from requests.exceptions import ConnectionError as BotoConnectionError
@@ -127,7 +128,7 @@ def upload_to_gcp_storage(bucket_name, source_file_name, destination_blob_name):
     return uploaded
 
 
-def gcp_bucket_to_dataset(gcp_bucket_name, file_name, dataset_name, table_name):
+def gcp_bucket_to_dataset(gcp_bucket_name, file_name, dataset_name, table_name, resource_level=False):
     """
     Create a gcp dataset from a file stored in a bucket.
 
@@ -162,128 +163,145 @@ def gcp_bucket_to_dataset(gcp_bucket_name, file_name, dataset_name, table_name):
 
         table_id = f"{project_name}.{dataset_name}.{table_name}"
 
+        # Build schema
+        schema = [
+            {"name": "billing_account_id", "type": "STRING", "mode": "NULLABLE"},
+            {
+                "name": "service",
+                "type": "RECORD",
+                "fields": [
+                    {"name": "id", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "description", "type": "STRING", "mode": "NULLABLE"},
+                ],
+                "mode": "NULLABLE",
+            },
+            {
+                "name": "sku",
+                "type": "RECORD",
+                "fields": [
+                    {"name": "id", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "description", "type": "STRING", "mode": "NULLABLE"},
+                ],
+                "mode": "NULLABLE",
+            },
+            {"name": "usage_start_time", "type": "TIMESTAMP", "mode": "NULLABLE"},
+            {"name": "usage_end_time", "type": "TIMESTAMP", "mode": "NULLABLE"},
+            {
+                "name": "project",
+                "type": "RECORD",
+                "fields": [
+                    {"name": "id", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "number", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "name", "type": "STRING", "mode": "NULLABLE"},
+                    {
+                        "name": "labels",
+                        "type": "RECORD",
+                        "fields": [
+                            {"name": "key", "type": "STRING", "mode": "NULLABLE"},
+                            {"name": "value", "type": "STRING", "mode": "NULLABLE"},
+                        ],
+                        "mode": "REPEATED",
+                    },
+                    {"name": "ancestry_numbers", "type": "STRING", "mode": "NULLABLE"},
+                ],
+                "mode": "NULLABLE",
+            },
+            {
+                "name": "labels",
+                "type": "RECORD",
+                "fields": [
+                    {"name": "key", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "value", "type": "STRING", "mode": "NULLABLE"},
+                ],
+                "mode": "REPEATED",
+            },
+            {
+                "name": "system_labels",
+                "type": "RECORD",
+                "fields": [
+                    {"name": "key", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "value", "type": "STRING", "mode": "NULLABLE"},
+                ],
+                "mode": "REPEATED",
+            },
+            {
+                "name": "location",
+                "type": "RECORD",
+                "fields": [
+                    {"name": "location", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "country", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "region", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "zone", "type": "STRING", "mode": "NULLABLE"},
+                ],
+                "mode": "NULLABLE",
+            },
+            {"name": "export_time", "type": "TIMESTAMP", "mode": "NULLABLE"},
+            {"name": "cost", "type": "FLOAT", "mode": "NULLABLE"},
+            {"name": "currency", "type": "STRING", "mode": "NULLABLE"},
+            {"name": "currency_conversion_rate", "type": "FLOAT", "mode": "NULLABLE"},
+            {
+                "name": "usage",
+                "type": "RECORD",
+                "fields": [
+                    {"name": "amount", "type": "FLOAT", "mode": "NULLABLE"},
+                    {"name": "unit", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "amount_in_pricing_units", "type": "FLOAT", "mode": "NULLABLE"},
+                    {"name": "pricing_unit", "type": "STRING", "mode": "NULLABLE"},
+                ],
+                "mode": "NULLABLE",
+            },
+            {
+                "name": "credits",
+                "type": "RECORD",
+                "fields": [
+                    {"name": "name", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "amount", "type": "FLOAT", "mode": "NULLABLE"},
+                    {"name": "full_name", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "id", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "type", "type": "STRING", "mode": "NULLABLE"},
+                ],
+                "mode": "REPEATED",
+            },
+            {
+                "name": "invoice",
+                "type": "RECORD",
+                "fields": [{"name": "month", "type": "STRING", "mode": "NULLABLE"}],
+                "mode": "NULLABLE",
+            },
+            {"name": "cost_type", "type": "STRING", "mode": "NULLABLE"},
+            {
+                "name": "adjustment_info",
+                "type": "RECORD",
+                "fields": [
+                    {"name": "id", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "description", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "mode", "type": "STRING", "mode": "NULLABLE"},
+                    {"name": "type", "type": "STRING", "mode": "NULLABLE"},
+                ],
+                "mode": "NULLABLE",
+            },
+        ]
+
+        # Add resource to schema if required
+        if resource_level:
+            schema += [
+                {
+                    "name": "resource",
+                    "type": "RECORD",
+                    "fields": [
+                        {"name": "name", "type": "STRING", "mode": "NULLABLE"},
+                        {"name": "global_name", "type": "STRING", "mode": "NULLABLE"},
+                    ],
+                    "mode": "NULLABLE",
+                }
+            ]
+
         # creates the job config with specifics
         job_config = bigquery.LoadJobConfig(
             write_disposition=bigquery.WriteDisposition.WRITE_TRUNCATE,
             source_format=bigquery.SourceFormat.NEWLINE_DELIMITED_JSON,
             time_partitioning=bigquery.TimePartitioning(),
-            schema=[
-                {"name": "billing_account_id", "type": "STRING", "mode": "NULLABLE"},
-                {
-                    "name": "service",
-                    "type": "RECORD",
-                    "fields": [
-                        {"name": "id", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "description", "type": "STRING", "mode": "NULLABLE"},
-                    ],
-                    "mode": "NULLABLE",
-                },
-                {
-                    "name": "sku",
-                    "type": "RECORD",
-                    "fields": [
-                        {"name": "id", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "description", "type": "STRING", "mode": "NULLABLE"},
-                    ],
-                    "mode": "NULLABLE",
-                },
-                {"name": "usage_start_time", "type": "TIMESTAMP", "mode": "NULLABLE"},
-                {"name": "usage_end_time", "type": "TIMESTAMP", "mode": "NULLABLE"},
-                {
-                    "name": "project",
-                    "type": "RECORD",
-                    "fields": [
-                        {"name": "id", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "number", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "name", "type": "STRING", "mode": "NULLABLE"},
-                        {
-                            "name": "labels",
-                            "type": "RECORD",
-                            "fields": [
-                                {"name": "key", "type": "STRING", "mode": "NULLABLE"},
-                                {"name": "value", "type": "STRING", "mode": "NULLABLE"},
-                            ],
-                            "mode": "REPEATED",
-                        },
-                        {"name": "ancestry_numbers", "type": "STRING", "mode": "NULLABLE"},
-                    ],
-                    "mode": "NULLABLE",
-                },
-                {
-                    "name": "labels",
-                    "type": "RECORD",
-                    "fields": [
-                        {"name": "key", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "value", "type": "STRING", "mode": "NULLABLE"},
-                    ],
-                    "mode": "REPEATED",
-                },
-                {
-                    "name": "system_labels",
-                    "type": "RECORD",
-                    "fields": [
-                        {"name": "key", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "value", "type": "STRING", "mode": "NULLABLE"},
-                    ],
-                    "mode": "REPEATED",
-                },
-                {
-                    "name": "location",
-                    "type": "RECORD",
-                    "fields": [
-                        {"name": "location", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "country", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "region", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "zone", "type": "STRING", "mode": "NULLABLE"},
-                    ],
-                    "mode": "NULLABLE",
-                },
-                {"name": "export_time", "type": "TIMESTAMP", "mode": "NULLABLE"},
-                {"name": "cost", "type": "FLOAT", "mode": "NULLABLE"},
-                {"name": "currency", "type": "STRING", "mode": "NULLABLE"},
-                {"name": "currency_conversion_rate", "type": "FLOAT", "mode": "NULLABLE"},
-                {
-                    "name": "usage",
-                    "type": "RECORD",
-                    "fields": [
-                        {"name": "amount", "type": "FLOAT", "mode": "NULLABLE"},
-                        {"name": "unit", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "amount_in_pricing_units", "type": "FLOAT", "mode": "NULLABLE"},
-                        {"name": "pricing_unit", "type": "STRING", "mode": "NULLABLE"},
-                    ],
-                    "mode": "NULLABLE",
-                },
-                {
-                    "name": "credits",
-                    "type": "RECORD",
-                    "fields": [
-                        {"name": "name", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "amount", "type": "FLOAT", "mode": "NULLABLE"},
-                        {"name": "full_name", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "id", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "type", "type": "STRING", "mode": "NULLABLE"},
-                    ],
-                    "mode": "REPEATED",
-                },
-                {
-                    "name": "invoice",
-                    "type": "RECORD",
-                    "fields": [{"name": "month", "type": "STRING", "mode": "NULLABLE"}],
-                    "mode": "NULLABLE",
-                },
-                {"name": "cost_type", "type": "STRING", "mode": "NULLABLE"},
-                {
-                    "name": "adjustment_info",
-                    "type": "RECORD",
-                    "fields": [
-                        {"name": "id", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "description", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "mode", "type": "STRING", "mode": "NULLABLE"},
-                        {"name": "type", "type": "STRING", "mode": "NULLABLE"},
-                    ],
-                    "mode": "NULLABLE",
-                },
-            ],
+            schema=schema,
         )
 
         uri = f"gs://{gcp_bucket_name}/{file_name}"
@@ -327,28 +345,38 @@ def upload_to_oci_bucket(bucket_name, report_type, file_name):
         (Boolean): True if file was uploaded
     """
 
-    uploaded = False
-
-    if "OCI_CONFIG_FILE" not in os.environ:
-        LOG.warning(
-            "Please set your OCI_CONFIG_FILE "
-            "environment variable before attempting to upload data to an oci bucket."
-        )
-        return uploaded
-
     try:
-        config = from_file(file_location=os.environ["OCI_CONFIG_FILE"])
-
+        if "OCI_CONFIG_FILE" in os.environ:
+            config = from_file(file_location=os.environ.get("OCI_CONFIG_FILE"))
+            LOG.info("Using configurations from config file.")
+        else:
+            oci_user = os.environ["OCI_USER"]
+            oci_fingerprint = os.environ["OCI_FINGERPRINT"]
+            oci_tenancy = os.environ["OCI_TENANCY"]
+            oci_credentials = os.environ["OCI_CREDENTIALS"]
+            oci_region = os.environ["OCI_REGION"]
+            oci_namespace = os.environ["OCI_NAMESPACE"]
+            for oci_var in [oci_user, oci_fingerprint, oci_tenancy, oci_credentials, oci_region, oci_namespace]:
+                if oci_var is None or oci_var == "":
+                    raise InvalidConfig("Must provide a valid config variables.")
+            config = {
+                "user": oci_user,
+                "fingerprint": oci_fingerprint,
+                "tenancy": oci_tenancy,
+                "key_content": oci_credentials,
+                "region": oci_region,
+                "namespace": oci_namespace,
+            }
+            LOG.info("Creating config dict from env vars.")
         validate_config(config)
         object_storage_client = ObjectStorageClient(config)
         namespace = object_storage_client.get_namespace().data
-
         with open(file_name, "rb") as file_in:
             with gzip.open(f"{file_name}.gz", "wb") as file_out:
                 shutil.copyfileobj(file_in, file_out)
         zipped_file = file_out
-
         upload_file_name = f"reports/{report_type}/{zipped_file.name}"
+
         object_storage_client.put_object(
             namespace,
             bucket_name,
@@ -356,10 +384,9 @@ def upload_to_oci_bucket(bucket_name, report_type, file_name):
             io.open(zipped_file.name, "rb"),
         )
 
-        LOG.info(f"File {upload_file_name} uploaded to OCI Storage {bucket_name} bucket.")
+        LOG.warning(f"File {upload_file_name} uploaded to OCI Storage {bucket_name} bucket.")
         os.remove(zipped_file.name)
-        uploaded = True
-    except (ServiceError, InvalidConfig, ConfigFileNotFound) as upload_err:
-        LOG.error(upload_err)
-        uploaded = False
-    return uploaded
+        return True
+    except (InvalidConfig, InvalidPrivateKey, ServiceError, ConfigFileNotFound) as err:
+        LOG.error(f"Error uploading report to oci bucket: {err}")
+        return False
